// Created on: 2015-08-06
// Created by: Ilya Novikov
// Copyright (c) 2004-2014 OPEN CASCADE SAS
//
// This file is part of Open CASCADE Technology software library.
//
// This library is free software; you can redistribute it and/or modify it under
// the terms of the GNU Lesser General Public License version 2.1 as published
// by the Free Software Foundation, with special exception defined in the file
// OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
// distribution for complete text of the license and disclaimer of any warranty.
//
// Alternatively, this file may be used under the terms of Open CASCADE
// commercial license or contractual agreement.

#ifndef _XCAFDimTolObjects_DatumTargetType_HeaderFile
#define _XCAFDimTolObjects_DatumTargetType_HeaderFile

//! Defines types of dimension
enum XCAFDimTolObjects_DatumTargetType
{
  XCAFDimTolObjects_DatumTargetType_Point,
  XCAFDimTolObjects_DatumTargetType_Line,
  XCAFDimTolObjects_DatumTargetType_Rectangle,
  XCAFDimTolObjects_DatumTargetType_Circle,
  XCAFDimTolObjects_DatumTargetType_Area
};

#endif // _XCAFDimTolObjects_DatumTargetType_HeaderFile
